@@ -18,11 +18,11 @@ Mojo::Pg::Che - mix of parent Mojo::Pg and DBI.pm
 
 =head1 VERSION
 
-Version 0.06
+Version 0.070
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.070';
 
 
 =head1 SYNOPSIS
@@ -80,12 +80,13 @@ our $VERSION = '0.06';
   };
   die $@ if $@;
   
-  my $tx = $pg->begin;
-  $tx->do('insert into foo (name) values (?)', 'bazzzz');
-  $tx->rollback;
-  $tx->begin;
-  $tx->query('insert into foo (name) values (?)', 'barrr');
-  $tx->commit;
+  my $db = $pg->db;
+  $db->begin;
+  $db->do('insert into foo (name) values (?)', 'bazzzz');
+  $db->rollback;
+  $db->begin;
+  $db->query('insert into foo (name) values (?)', 'barrr');
+  $db->commit;
 
 =head1 Non-blocking query cases
 
@@ -119,14 +120,6 @@ All methods from parent module L<Mojo::Pg> are inherits and implements the follo
 
 DBI-style of new object instance. See L<DBI#connect>
 
-=head2 query
-
-Like L<Mojo::Pg::Database#query> but input params - L<Mojo::Pg::Che#Params-for-quering-methods>
-
-Blocking query without attr B<Async> or callback.
-
-Non-blocking query with attr B<Async> or callback.
-
 =head2 db
 
 Overriden method of L<Mojo::Pg#db>. Because can first input param - DBI database handler (when prepared statement used).
@@ -139,41 +132,49 @@ Prepare and return DBI statement handler for query string.
 
 Prepare and return DBI cached statement handler for query string.
 
+=head2 query
+
+Like L<Mojo::Pg::Database#query> but input params - L<Mojo::Pg::Che#Params-for-quering-methods>
+
+Blocking query without attr B<Async> or callback.
+
+Non-blocking query with attr B<Async> or callback.
+
 =head2 selectrow_array
 
-DBI style quering. See L<DBI#selectrow_array>. Blocking|non-blocking, query string|statement handler. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
+DBI style quering. See L<DBI#selectrow_array>. Blocking | non-blocking. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
 
 =head2 selectrow_arrayref
 
-DBI style quering. See L<DBI#selectrow_arrayref>. Blocking|non-blocking, query string|statement handler. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
+DBI style quering. See L<DBI#selectrow_arrayref>. Blocking | non-blocking. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
 
 =head2 selectrow_hashref
 
-DBI style quering. See L<DBI#selectrow_hashref>. Blocking|non-blocking, query string|statement handler. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
+DBI style quering. See L<DBI#selectrow_hashref>. Blocking | non-blocking. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
 
 =head2 selectall_arrayref
 
-DBI style quering. See L<DBI#selectall_arrayref>. Blocking|non-blocking, query string|statement handler. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
+DBI style quering. See L<DBI#selectall_arrayref>. Blocking | non-blocking. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
 
 =head2 selectall_hashref
 
-DBI style quering. See L<DBI#selectall_hashref>. Blocking|non-blocking, query string|statement handler. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
+DBI style quering. See L<DBI#selectall_hashref>. Blocking | non-blocking. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
 
 =head2 selectcol_arrayref
 
-DBI style quering. See L<DBI#selectcol_arrayref>. Blocking|non-blocking, query string|statement handler. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
+DBI style quering. See L<DBI#selectcol_arrayref>. Blocking | non-blocking. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
 
 =head2 do
 
-DBI style quering. See L<DBI#do>. Blocking|non-blocking, query string|statement handler. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
+DBI style quering. See L<DBI#do>. Blocking | non-blocking. Input params - L<Mojo::Pg::Che#Params-for-quering-methods>.
 
 =head2 begin
 
-Start transaction and return new <Mojo::Pg::Che::Database> object which attr C< {tx} > is a <Mojo::Pg::Transaction> object. Sinonyms are: C<< ->tx >> and C<< ->begin_work >>.
+Start transaction and return new L<Mojo::Pg::Che::Database> object which attr C< {tx} > is a L<Mojo::Pg::Transaction> object. Sinonyms are: C<< ->tx >> and C<< ->begin_work >>.
 
 =head1 Params for quering methods
 
-The methods C<query>, C<select...>, C<do> has next input params:
+The methods C<query>, C<select...>, C<do> has next ordered input params:
 
 =over 4
 
@@ -183,10 +184,16 @@ The methods C<query>, C<select...>, C<do> has next input params:
 
 =item * Array of bind values (optional)
 
-=item * Callback non-blocking (optional)
+=item * Last param - callback/coderef for non-blocking (optional)
 
 =back
 
+=head1 SEE ALSO
+
+L<Mojo::Pg>
+
+L<DBI>
+
 =head1 AUTHOR
 
 Михаил Че (Mikhail Che), C<< <mche[-at-]cpan.org> >>
@@ -206,7 +213,7 @@ it under the same terms as Perl itself.
 
 use Carp qw(croak);
 
-has db_class => sub {
+has database_class => sub {
   require Mojo::Pg::Che::Database;
   'Mojo::Pg::Che::Database';
 };
@@ -268,7 +275,7 @@ sub db {
   
   $dbh ||= $self->_dequeue;
 
-  return $self->db_class->new(dbh => $dbh, pg => $self);
+  return $self->database_class->new(dbh => $dbh, pg => $self);
 }
 
 sub prepare { shift->db->prepare(@_); }
@@ -307,8 +314,7 @@ sub _dequeue {
   for my $i (0..$#$queue) {
     
     my $dbh = $queue->[$i];
-    
-    #~ warn "pg_async_status: ", $dbh->{pg_async_status} and
+
     next
       if $dbh->{pg_async_status} && $dbh->{pg_async_status} > 0;
     
